@@ -3,8 +3,8 @@ from django.db import models
 from django.contrib.auth import models as auth_models
 
 class Clipboard(models.Model):
-    user = models.ForeignKey(auth_models.User, related_name="clipboards")
-    files = models.ManyToManyField('File', related_name="clipboards", through='ClipboardItem')
+    user = models.ForeignKey(auth_models.User, related_name="filer_clipboards")
+    files = models.ManyToManyField('File', related_name="in_clipboards", through='ClipboardItem')
     
     def append_file(self, file):
         newitem = ClipboardItem(file=file, clipboard=self)
@@ -20,9 +20,12 @@ class Clipboard(models.Model):
         return u"Clipboard %s of %s" % (self.id, self.user)
     class Meta:
         app_label = 'filer'
+        verbose_name = _('Clipboard')
 
 class ClipboardItem(models.Model):
     file = models.ForeignKey('File')
     clipboard = models.ForeignKey(Clipboard)
     class Meta:
-        app_label = 'filer'
\ No newline at end of file
+        app_label = 'filer'
+        verbose_name = _('Clipboard item')
+        verbose_name_plural = _('Clipboard items')
\ No newline at end of file
