@@ -4,31 +4,32 @@ from django.db import models
 from django.contrib.auth import models as auth_models
 
 from django.conf import settings
-from filer.models.safe_file_storage import SafeFilenameFileSystemStorage
+from filer.models.filer_file_storage import get_directory_name
 from filer.models.foldermodels import Folder
-from filer.settings import FILER_UPLOAD_ROOT
 from filer.models import mixins
 
-fs = SafeFilenameFileSystemStorage()
     
 
 class File(models.Model, mixins.IconsMixin):
     _icon = "file"
     folder = models.ForeignKey(Folder, related_name='all_files', null=True, blank=True)
-    file_field = models.FileField(upload_to=FILER_UPLOAD_ROOT, storage=fs, null=True, blank=True,max_length=255)
-    _file_type_plugin_name = models.CharField(_("file_type_plugin_name"), max_length=128, null=True, blank=True, editable=False)
+    _file = models.FileField(upload_to=get_directory_name, null=True, blank=True, max_length=255)
+    _file_type_plugin_name = models.CharField("file_type_plugin_name", max_length=128, null=True, blank=True, editable=False)
     _file_size = models.IntegerField(null=True, blank=True)
     
     has_all_mandatory_data = models.BooleanField(default=False, editable=False)
     
     original_filename = models.CharField(max_length=255, blank=True, null=True)
-    name = models.CharField(max_length=255, null=True, blank=True)
+    name = models.CharField(max_length=255, null=True, blank=True, verbose_name=_('Name'))
+    description = models.TextField(null=True, blank=True, verbose_name=_('Description'))
     
-    owner = models.ForeignKey(auth_models.User, related_name='owned_%(class)ss', null=True, blank=True)
+    owner = models.ForeignKey(auth_models.User, related_name='owned_%(class)ss', null=True, blank=True, verbose_name=_('Owner'))
     
     uploaded_at = models.DateTimeField(auto_now_add=True)
     modified_at = models.DateTimeField(auto_now=True)
     
+    #is_public = models.BooleanField(default=True)
+    
     # TODO: Factor out customer specific fields... maybe a m2m?
     #can_use_for_web = models.BooleanField(default=True)
     #can_use_for_print = models.BooleanField(default=True)
@@ -45,7 +46,7 @@ class File(models.Model, mixins.IconsMixin):
             text = self.original_filename or 'unnamed file'
         else:
             text = self.name
-        text = u"%s [%s]" % (text, self.__class__.__name__)
+        text = u"%s" % (text,)
         return text
     
     def has_edit_permission(self, request):
@@ -87,11 +88,12 @@ class File(models.Model, mixins.IconsMixin):
             pass
         elif issubclass(self.__class__, File):
             self._file_type_plugin_name = self.__class__.__name__
-        
+        # cache the file size
         try:
-            self._file_size = self.file_field.size
+            self._file_size = self._file.size
         except:
             pass
+        
         super(File, self).save(*args,**kwargs)
     
     def subtype(self):
@@ -108,19 +110,23 @@ class File(models.Model, mixins.IconsMixin):
         return r
     def get_admin_url_path(self):
         return urlresolvers.reverse('admin:filer_file_change', args=(self.id,))
-    def  url(self):
+    @property
+    def url(self):
+        '''
+        to make the model behave like a file field
+        '''
         try:
-            r = self.file_field.url
+            r = self._file.url
         except:
             r = ''
         return r
     @property
     def file(self):
-        return self.file_field.file
+        return self._file.file
     @property
     def path(self):
         try:
-            return self.file_field.path
+            return self._file.path
         except:
             return ""
     @property
@@ -138,6 +144,19 @@ class File(models.Model, mixins.IconsMixin):
             return UnfiledImages()
         else:
             return self.folder
+    @property
+    def logical_path(self):
+        """
+        Gets logical path of the folder in the tree structure.
+        Used to generate breadcrumbs
+        """
+        folder_path = []
+        if self.folder:
+            folder_path.extend(self.folder.get_ancestors())
+        folder_path.append(self.logical_folder)
+        return folder_path     
+        
     class Meta:
         app_label = 'filer'
-
+        verbose_name = _('File')
+        verbose_name_plural = _('Files')
