@@ -90,7 +90,7 @@ class Folder(models.Model, mixins.IconsMixin):
     parent = models.ForeignKey('self', null=True, blank=True, related_name='children')
     name = models.CharField(max_length=255)
     
-    owner = models.ForeignKey(auth_models.User, related_name='owned_folders', null=True, blank=True)
+    owner = models.ForeignKey(auth_models.User, related_name='filer_owned_folders', null=True, blank=True)
     
     uploaded_at = models.DateTimeField(auto_now_add=True)
     
@@ -115,6 +115,17 @@ class Folder(models.Model, mixins.IconsMixin):
     @property
     def files(self):
         return self.all_files.all()
+    @property
+    def logical_path(self):
+        """
+        Gets logical path of the folder in the tree structure.
+        Used to generate breadcrumbs
+        """
+        folder_path = []
+        if self.parent:
+            folder_path.extend(self.parent.get_ancestors())
+            folder_path.append(self.parent)
+        return folder_path
     
     def has_edit_permission(self, request):
         return self.has_generic_permission(request, 'edit')
@@ -152,6 +163,7 @@ class Folder(models.Model, mixins.IconsMixin):
         return urlresolvers.reverse('admin:filer_folder_change', args=(self.id,))
     def get_admin_directory_listing_url_path(self):
         return urlresolvers.reverse('admin:filer-directory_listing', args=(self.id,))
+        
     def __unicode__(self):
         return u"%s" % (self.name,)
     class Meta:
@@ -179,8 +191,8 @@ class FolderPermission(models.Model):
     folder = models.ForeignKey(Folder, null=True, blank=True)
     
     type = models.SmallIntegerField(_('type'), choices=TYPES, default=0)
-    user = models.ForeignKey(auth_models.User, verbose_name=_("user"), blank=True, null=True)
-    group = models.ForeignKey(auth_models.Group, verbose_name=_("group"), blank=True, null=True)
+    user = models.ForeignKey(auth_models.User, related_name="filer_folder_permissions", verbose_name=_("user"), blank=True, null=True)
+    group = models.ForeignKey(auth_models.Group, related_name="filer_folder_permissions", verbose_name=_("group"), blank=True, null=True)
     everybody = models.BooleanField(_("everybody"), default=False)
     
     can_edit = models.BooleanField(_("can edit"), default=True)
